@@ -79,7 +79,6 @@ def _write_pixels(output_file, pixel_source, palette):
     saving_bitmap = isinstance(pixel_source, Bitmap)
     width, height = _rotated_height_and_width(pixel_source)
     row_buffer = bytearray(_bytes_per_row(width))
-    result_buffer = bytearray(2048)
     for y in range(height, 0, -1):
         buffer_index = 0
         if saving_bitmap:
@@ -91,6 +90,7 @@ def _write_pixels(output_file, pixel_source, palette):
                     color >>= 8
                     buffer_index += 1
         else:
+            result_buffer = bytearray(2048)
             data = pixel_source.fill_row(y - 1, result_buffer)
             for i in range(width):
                 pixel565 = (data[i * 2] << 8) + data[i * 2 + 1]
@@ -127,7 +127,9 @@ def save_pixels(file_or_filename, pixel_source=None, palette=None):
         raise ValueError("Second argument must be a Bitmap or Display")
     try:
         if isinstance(file_or_filename, str):
-            output_file = open(file_or_filename, "wb")
+            output_file = open(  # pylint: disable=consider-using-with
+                file_or_filename, "wb"
+            )
         else:
             output_file = file_or_filename
 
